function [ preds, s2, expectations, variances ] = historical_average_model( X_train, y_train, X_test )
%HISTORICAL_AVERAGE_MODEL Makes predicitons based on day of week and time
%of day
%   INPUT: X_train is data matrix with [day of week, time of day]; similar
%   for X_test; y_train are the observations (dependent variable)
    
    dows = unique(X_train(:,1));
    tods = unique(X_train(:,2));
    sum_values = zeros(numel(dows), numel(tods));
    ss_values = zeros(numel(dows), numel(tods));
    counts = zeros(numel(dows), numel(tods));
    
    for n = 1:size(X_train,1)
        if isnan(y_train(n))
            continue;
        end
        dow = find(dows == X_train(n,1));
        tod = find(tods == X_train(n,2));
        sum_values(dow, tod) = sum_values(dow, tod) + y_train(n);
        ss_values(dow, tod) = ss_values(dow, tod) + (y_train(n)^2);
        counts(dow, tod) = counts(dow, tod) + 1.0;
    end
    
    expectations = sum_values ./ counts;
    variances = (ss_values ./ counts) - (expectations.^2);

    preds = zeros(size(X_test,1), 1);
    s2 = zeros(size(X_test,1), 1);
    for n = 1:size(X_test,1)
        dow = find(dows == X_test(n,1));
        tod = find(tods == X_test(n,2));
        preds(n) = expectations(dow, tod);
        s2(n) = variances(dow, tod);
    end
end

