clear all;

rng(42); % for reproducibility

% ---------------------------------- Options
prob_miss = 0.50;
prob_stay = 0.8;

% load dataset
load 'norrecampus_data_multi'

% % use detrended data instead
% for i=1:numel(speeds)
%     speeds{i}.values = detrended_speeds{i}.values;
% end

N = size(speeds{1}.values,1);
fprintf('N: %d\n', N);

y = {};
y_true = {};
for i=1:numel(place_ids)
    fprintf('Preparing data for place id %s...\n', place_ids{i});
    assert(size(speeds{i}.values,1) == N);
    
    % compute snr
    fprintf('SNR: %f\n', snr(speeds{i}.values));
    
    % add missing data (but make sure they were not missings originally)
    ix_missings = [];
    ix = 1;
    n = 1;
    state = 0; % state 1 is missing
    while (n < N)
        if state % if in missing state
            if (rand() < prob_stay) && (~missing_speeds{i}.values(n)) % chances of staying in missing
                ix_missings = [ix_missings, n];
                ix = ix + 1;
            else
                state = 0;
            end
        else % not on missing state
            if (rand() < prob_miss) && (~missing_speeds{i}.values(n)) % chances of going into missing state
                ix_missings = [ix_missings, n];
                ix = ix + 1;
                state = 1;
            end
        end
            
        n = n + 1;
    end
    fprintf('num missings obtained: %d out of %d (%f percent)\n', numel(ix_missings), N, 1.0*numel(ix_missings)/N)
    fprintf('got to n=%d out of %d (if they match, we reaches the end of the dataset before we have all the missings)\n', n, N);
    
    
    % build train and test data for imputation
    y_true{i} = speeds{i}.values;
    y{i} = speeds{i}.values;
    y{i}(ix_missings) = nan;
    Xvar{i} = lagmatrix(flows{i}.values, [1,2,3,4,5]);
    Xvar{i}(isnan(Xvar{i})) = Xvar{i}(2);
end

% save prepared data
save(['norrecampus_imputation_multi_blocks',num2str(prob_miss*100),'_',num2str(prob_stay*100),'_.mat'], 'place_ids', 'Xvar', 'y', 'y_true', 'metadata', 'detrended_speeds')

