clear all;

warning('off')
maxNumCompThreads(str2num(getenv('PBS_NUM_PPN')));

startup_multigp

rng(42); % fix seed for reproducibility

% ---------------------------------- Options
% simple norrecampus
%selected_place_ids = {'ChIJf9Y9sFdSUkYRmaDEJhCweGc', 'ChIJP6TdhFdSUkYRdrsWKXZMAs8'}; % place before
%selected_place_ids = {'ChIJf9Y9sFdSUkYRmaDEJhCweGc', 'ChIJozaGTFZSUkYRNtWl2AGUPkI'}; % place after
%selected_place_ids = {'ChIJP6TdhFdSUkYRdrsWKXZMAs8', 'ChIJf9Y9sFdSUkYRmaDEJhCweGc', 'ChIJozaGTFZSUkYRNtWl2AGUPkI'};

% lake
%selected_place_ids = {'ChIJ253ssvxSUkYR23C5RnVMJqQ', 'ChIJ7yG8rvxSUkYRCyLM4COKDkg'}; % place before
%selected_place_ids = {'ChIJ253ssvxSUkYR23C5RnVMJqQ', 'ChIJs8phS-NSUkYROIpWCWQi4Xg'}; % place after
%selected_place_ids = {'ChIJ253ssvxSUkYR23C5RnVMJqQ', 'ChIJ37rdi_9SUkYR2RWqxZuK9Qc'}; % place far away
%selected_place_ids = {'ChIJ7yG8rvxSUkYRCyLM4COKDkg', 'ChIJ253ssvxSUkYR23C5RnVMJqQ', 'ChIJs8phS-NSUkYROIpWCWQi4Xg'};

% not norrecampus
selected_place_ids = {'ChIJC9rTcFRSUkYRmFW7zncNe04', 'ChIJ48PFi1NSUkYRfzcCtz1u4Lw'}; % place before
%selected_place_ids = {'ChIJC9rTcFRSUkYRmFW7zncNe04', 'ChIJGQ9eZlRSUkYRQTPpEdlphBw'}; % place after
%selected_place_ids = {'ChIJ48PFi1NSUkYRfzcCtz1u4Lw', 'ChIJC9rTcFRSUkYRmFW7zncNe04', 'ChIJGQ9eZlRSUkYRQTPpEdlphBw'};

% crossing norrecampus
%selected_place_ids = {'ChIJqeYPY1VSUkYR34lDp5Cl-8g', 'ChIJT9erZFVSUkYRNiSDTV-sJzE'}; % place before
%selected_place_ids = {'ChIJqeYPY1VSUkYR34lDp5Cl-8g', 'ChIJ37rdi_9SUkYR2RWqxZuK9Qc'}; % place after
%selected_place_ids = {'ChIJqeYPY1VSUkYR34lDp5Cl-8g', 'ChIJ4zMOcFVSUkYRXtwIvYKTWjU'}; % place before crossing, to the left
%selected_place_ids = {'ChIJqeYPY1VSUkYR34lDp5Cl-8g', 'ChIJsde_glVSUkYRlK8i5BD3BOA'}; % place before crossing, to the right
%selected_place_ids = {'ChIJT9erZFVSUkYRNiSDTV-sJzE', 'ChIJqeYPY1VSUkYR34lDp5Cl-8g', 'ChIJ37rdi_9SUkYR2RWqxZuK9Qc'};
%selected_place_ids = {'ChIJ4zMOcFVSUkYRXtwIvYKTWjU', 'ChIJsde_glVSUkYRlK8i5BD3BOA', 'ChIJqeYPY1VSUkYR34lDp5Cl-8g'}; % two intersecting roads

selected_place_ids

total_size = 12*24*30*6; % num of data points: 12 * 24h * 30days * 6 months
block_size = 12*24*15; % 1 month blocks
num_blocks = total_size / block_size;
%display = 2;
display = 0;
iters = 100;

% load data
load norrecampus_imputation_multi75;

% use detrended time-series
for i=1:numel(y)
    y{i} = (y{i} - detrended_speeds{i}.removed_seasonality) / detrended_speeds{i}.removed_std;
    y_true{i} = (y_true{i} - detrended_speeds{i}.removed_seasonality) / detrended_speeds{i}.removed_std;
end

kern_nlf = 2;

q = 1;  % dimensionality of the input
d = numel(selected_place_ids);  % dimensionality of the output
    
% compute lag matrices
%lags_definition = [1:5, 7*12*24];
lags_definition = [-5:-1, 1:5, -7*12*24, 7*12*24];
lags = cell(d,1);
for place=1:numel(selected_place_ids)
    % find index for that place_id
    [~, ix] = max(cellfun(@(s) ~isempty(strfind(selected_place_ids{place}, s)), place_ids));
    lags{place} = lagmatrix(y{ix}, lags_definition);
    
    % do interpolation to fix nan's in the lags
    times = 1:size(lags{place},1);
    for i=1:size(lags{place},2)
        mask =  ~isnan(lags{place}(:,i));
        lags{place}(~mask,i) = interp1(times(mask), lags{place}(mask,i), times(~mask));
    end
    lags{place}(isnan(lags{place})) = mean(y_true{ix});
end

trues = cell(d,1);
preds_naive = cell(d,1); vars_naive = cell(d,1);
preds_cribbing = cell(d,1); vars_cribbing = cell(d,1);
preds_lr = cell(d,1); vars_lr = cell(d,1);
preds_lgp = cell(d,1); vars_lgp = cell(d,1);
preds_igp = cell(d,1); vars_igp = cell(d,1);
preds_multigp = cell(d,1); vars_multigp = cell(d,1);
last_obs = cell(d,1);
for place=1:numel(selected_place_ids)
    [~, ix] = max(cellfun(@(s) ~isempty(strfind(selected_place_ids{place}, s)), place_ids));
    last_obs{place} = 0;
end
for block=1:num_blocks
    fprintf('Running model for block %d of %d...\n', block, num_blocks);
    lo = (block-1)*block_size+1;
    hi = block*block_size;
    fprintf('lo=%d hi=%d\n', lo, hi);
    
    y_block = cell(d,1);
    y_true_block = cell(d,1);
    X_block = cell(d,1);
    missings = cell(d,1);
    non_missings = cell(d,1);
    X_train = cell(d+kern_nlf,1);
    y_train = cell(d+kern_nlf,1);
    X_test = cell(d+kern_nlf,1);
    y_test = cell(d,1);
    removed_std = cell(d,1);
    removed_seasonality = cell(d,1);
    for j=1:kern_nlf
       y_train{j} = [];
       X_train{j} = zeros(1, q);  
       X_test{j} = zeros(1, q); 
    end
    for place=1:numel(selected_place_ids)
        % find index for that place_id
        [~, ix] = max(cellfun(@(s) ~isempty(strfind(selected_place_ids{place}, s)), place_ids));
        
        y_block{place} = y{ix}(lo:hi);
        y_true_block{place} = y_true{ix}(lo:hi);
        X_block{place} = [1:size(y_block{place},1)]';
        assert(size(y_block{place},1) == size(y_block{place},1));
        
        % compute missings and non-missings
        missings{place} = isnan(y_block{place});
        non_missings{place} = X_block{place};
        non_missings{place}(missings{place}) = [];
        
        % normalize data
        mean_y = mean(y_true_block{place}); 
        std_y = std(y_true_block{place}); 
        y_block{place} = (y_block{place} - mean_y) / std_y;
        y_true_block{place} = (y_true_block{place} - mean_y) / std_y;
       
        removed_std{place} = detrended_speeds{ix}.removed_std;
        removed_seasonality{place} = detrended_speeds{ix}.removed_seasonality(lo:hi);
        
        % train/test split
        X_train{place+kern_nlf} = X_block{place}(non_missings{place},:);
        y_train{place+kern_nlf} = y_block{place}(non_missings{place},:);
        X_test{place+kern_nlf} = X_block{place}(missings{place},:);
        y_test{place} = y_true_block{place}(missings{place},:) * removed_std{place} + removed_seasonality{place}(missings{place},end);
        
        % linear regression and GP with lags from multiple places
        lags_train = []; 
        lags_test = [];
        for i=1:numel(y_block)
            lags_block = lags{i}(lo:hi,:);
            lags_train = [lags_train, lags_block(non_missings{place},:)];
            lags_test = [lags_test, lags_block(missings{place},:)];
        end
        disp('Running linear regression on lags of multiple places...')
        lr_model = fitlm(lags_train, y_train{place+kern_nlf});
        pred_lr = predict(lr_model, lags_test);
        pred_lr = pred_lr * removed_std{place} + removed_seasonality{place}(missings{place},end);
        preds_lr{place} = [preds_lr{place}; pred_lr];
        
        disp('Running GP on lags of multiple places...')
        options2 = gpOptions('ftc');
        options2.kern = 'ard';
        %options2.kern = 'matern32';
        %options2.kern = kernCreate(X{1}, {'matern32', 'rbf', 'white'});
        options2.optimiser = 'scg';
        options2.nlf = 1;
        model2 = gpCreate(size(lags_train,2), 1, lags_train, y_train{place+kern_nlf}, options2);
        model2 = gpOptimise(model2, display, iters);
        %modelDisplay(model2)
        [mu2, varsigma2] = gpPosteriorMeanVar(model2, lags_test);
        mu2 = mu2 * removed_std{place} + removed_seasonality{place}(missings{place},end);
        [corr, mae, rmse, rae, rrse, r2] = eval_predictions(mu2, y_test{place});
        fprintf('Test: %f\t%f\t%f\t%f\t%f\t%f\n', corr, mae, rmse, rae, rrse, r2)

        % independent GP
        disp('Running independent GP...')
        init_time = cputime; 
        options1 = gpOptions('ftc');
        %options1.kern = 'matern32';
        %options1.kern = kernCreate(X{1}, {'matern32', 'rbf', 'white'});
        options1.kern = kernCreate(X_train{place+kern_nlf}, {'rbfperiodic', 'rbf', 'white'});
        options1.kern.comp{1}.period = 7*12*24;
        options1.optimiser = 'scg';
        options1.nlf = 1;
        model1 = gpCreate(q, 1, X_train{place+kern_nlf}, y_train{place+kern_nlf}, options1);
        model1 = gpOptimise(model1, display, iters);
        %modelDisplay(model1)
        [mu1, varsigma1] = gpPosteriorMeanVar(model1, X_test{place+kern_nlf});
        mu1 = mu1 * removed_std{place} + removed_seasonality{place}(missings{place},end);
        elapsed_time = cputime - init_time;
        fprintf('Elapsed time: %f\n', elapsed_time)
        [corr, mae, rmse, rae, rrse, r2] = eval_predictions(mu1, y_test{place});
        fprintf('Test: %f\t%f\t%f\t%f\t%f\t%f\n', corr, mae, rmse, rae, rrse, r2)

        trues{place} = [trues{place}; y_test{place}];
        preds_igp{place} = [preds_igp{place}; mu1];
        vars_igp{place} = [vars_igp{place}; varsigma1];
        preds_lgp{place} = [preds_lgp{place}; mu2];
        vars_lgp{place} = [vars_lgp{place}; varsigma2];
    end
        
    % naive model that predicts previously observed value
    disp('Running naive and cribbing baselines...')
    preds_naive_block = cell(d,1);
    preds_cribbing_block = cell(d,1);
    for t=1:numel(y_block{1})
        for place=1:numel(selected_place_ids)
            % find index for that place_id
            [~, ix] = max(cellfun(@(s) ~isempty(strfind(selected_place_ids{place}, s)), place_ids));
            
            if ~isnan(y_block{place}(t))
                last_obs{place} = y_block{place}(t);
            else % it is a missing; we need to impute it
                % naive model that predicts previously observed value
                preds_naive_block{place} = [preds_naive_block{place}; last_obs{place}];
                %vars_naive{place} = [vars_naive{place}; std(y_true_block{place})^2];
                
                % cribbing model that copies the values from another
                % related time-series (if not missing as well)
                pred_cribbing = nan;
                for place2=1:numel(selected_place_ids)
                    if place2 ~= place && ~isnan(y_block{place2}(t))
                        pred_cribbing = y_block{place2}(t);
                        break;
                    end
                end
                if isnan(pred_cribbing)
                    pred_cribbing = last_obs{place};
                end
                preds_cribbing_block{place} = [preds_cribbing_block{place}; pred_cribbing];
                %vars_cribbing{place} = [vars_cribbing{place}; std(y_true_block{place})^2];
            end
        end
    end
    for place=1:d
        preds_naive{place} = [preds_naive{place}; preds_naive_block{place} * removed_std{place} + removed_seasonality{place}(missings{place},end)];
        preds_cribbing{place} = [preds_cribbing{place}; preds_cribbing_block{place} * removed_std{place} + removed_seasonality{place}(missings{place},end)];
    end
    
    % multi-output GP
    disp('Running multi-output GP...')
    init_time = cputime; 
    options = multigpOptions('ftc');
    options.kernType = 'gg';
    options.includeInd = true;
    %options.kern = 'rbf';
    %options.kern = 'matern32';
    %options.kern = kernCreate(X_train, {'matern32', 'rbf', 'white'});
    options.kern = kernCreate(X_train, {'rbfperiodic', 'rbf', 'white'});
    options.kern.comp{1}.period = 7*12*24;
    %options.kern.comp{2}.variance = log(10);
    %options.kern.comp{2}.inverseWidth = log(10);
    options.optimiser = 'scg';
    options.nlf = kern_nlf;
    model = multigpCreate(q, d+kern_nlf, X_train, y_train, options);
    
    model = multigpOptimise(model, display, iters);
    %modelDisplay(model)
    [mu, varsigma] = multigpPosteriorMeanVar(model, X_test);
    elapsed_time = cputime - init_time;
    fprintf('Elapsed time: %f\n', elapsed_time)
    
    % compute error and show results
    fprintf('\nResults after %d blocks of %d:\n', block, num_blocks)
    for place=1:d
        % find index for that place_id
        [~, ix] = max(cellfun(@(s) ~isempty(strfind(selected_place_ids{place}, s)), place_ids));
        
        pred_mgp = mu{place+kern_nlf} * removed_std{place} + removed_seasonality{place}(missings{place},end);
        var_mgp = varsigma{place+kern_nlf} * removed_std{place}^2;
        preds_multigp{place} = [preds_multigp{place}; pred_mgp];
        vars_multigp{place} = [vars_multigp{place}; var_mgp];
        
        fprintf('\nPlace id: %s\n', place_ids{ix})
        fprintf('           CorrCoef\tMAE\tRMSE\tRAE \tRRSE\tR2\tMPE\n')
        [corr, mae, rmse, rae, rrse, r2, mpe] = eval_predictions(preds_naive{place}, trues{place});
        fprintf('Naive:     %.3f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\n', corr, mae, rmse, rae, rrse, r2, mpe)
        [corr, mae, rmse, rae, rrse, r2, mpe] = eval_predictions(preds_cribbing{place}, trues{place});
        fprintf('Cribbing:  %.3f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\n', corr, mae, rmse, rae, rrse, r2, mpe)
        [corr, mae, rmse, rae, rrse, r2, mpe] = eval_predictions(preds_lr{place}, trues{place});
        fprintf('Lin. Reg.: %.3f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\n', corr, mae, rmse, rae, rrse, r2, mpe)
        [corr, mae, rmse, rae, rrse, r2, mpe] = eval_predictions(preds_lgp{place}, trues{place});
        fprintf('Lagged GP: %.3f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\n', corr, mae, rmse, rae, rrse, r2, mpe)
        [corr, mae, rmse, rae, rrse, r2, mpe] = eval_predictions(preds_igp{place}, trues{place});
        fprintf('Indep. GP: %.3f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\n', corr, mae, rmse, rae, rrse, r2, mpe)
        [corr, mae, rmse, rae, rrse, r2, mpe] = eval_predictions(preds_multigp{place}, trues{place});
        fprintf('Multi-GP:  %.3f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\n', corr, mae, rmse, rae, rrse, r2, mpe)
    end
end

