clear all;

rng(42); % fix seed for reproducibility

% ---------------------------------- Options
% simple norrecampus
%selected_place_ids = {'ChIJf9Y9sFdSUkYRmaDEJhCweGc', 'ChIJP6TdhFdSUkYRdrsWKXZMAs8'}; % place before
%selected_place_ids = {'ChIJf9Y9sFdSUkYRmaDEJhCweGc', 'ChIJozaGTFZSUkYRNtWl2AGUPkI'}; % place after
%selected_place_ids = {'ChIJP6TdhFdSUkYRdrsWKXZMAs8', 'ChIJf9Y9sFdSUkYRmaDEJhCweGc', 'ChIJozaGTFZSUkYRNtWl2AGUPkI'};

% lake
%selected_place_ids = {'ChIJ253ssvxSUkYR23C5RnVMJqQ', 'ChIJ7yG8rvxSUkYRCyLM4COKDkg'}; % place before
%selected_place_ids = {'ChIJ253ssvxSUkYR23C5RnVMJqQ', 'ChIJs8phS-NSUkYROIpWCWQi4Xg'}; % place after
%selected_place_ids = {'ChIJ253ssvxSUkYR23C5RnVMJqQ', 'ChIJ37rdi_9SUkYR2RWqxZuK9Qc'}; % place far away
%selected_place_ids = {'ChIJ7yG8rvxSUkYRCyLM4COKDkg', 'ChIJ253ssvxSUkYR23C5RnVMJqQ', 'ChIJs8phS-NSUkYROIpWCWQi4Xg'};

% not norrecampus
%selected_place_ids = {'ChIJC9rTcFRSUkYRmFW7zncNe04', 'ChIJ48PFi1NSUkYRfzcCtz1u4Lw'}; % place before
%selected_place_ids = {'ChIJC9rTcFRSUkYRmFW7zncNe04', 'ChIJGQ9eZlRSUkYRQTPpEdlphBw'}; % place after
%selected_place_ids = {'ChIJ48PFi1NSUkYRfzcCtz1u4Lw', 'ChIJC9rTcFRSUkYRmFW7zncNe04', 'ChIJGQ9eZlRSUkYRQTPpEdlphBw'};

% crossing norrecampus
%selected_place_ids = {'ChIJqeYPY1VSUkYR34lDp5Cl-8g', 'ChIJT9erZFVSUkYRNiSDTV-sJzE'}; % place before
%selected_place_ids = {'ChIJqeYPY1VSUkYR34lDp5Cl-8g', 'ChIJ37rdi_9SUkYR2RWqxZuK9Qc'}; % place after
%selected_place_ids = {'ChIJqeYPY1VSUkYR34lDp5Cl-8g', 'ChIJ4zMOcFVSUkYRXtwIvYKTWjU'}; % place before crossing, to the left
%selected_place_ids = {'ChIJqeYPY1VSUkYR34lDp5Cl-8g', 'ChIJsde_glVSUkYRlK8i5BD3BOA'}; % place before crossing, to the right
selected_place_ids = {'ChIJT9erZFVSUkYRNiSDTV-sJzE', 'ChIJqeYPY1VSUkYR34lDp5Cl-8g', 'ChIJ37rdi_9SUkYR2RWqxZuK9Qc'};
%selected_place_ids = {'ChIJ4zMOcFVSUkYRXtwIvYKTWjU', 'ChIJsde_glVSUkYRlK8i5BD3BOA', 'ChIJqeYPY1VSUkYR34lDp5Cl-8g'}; % two intersecting roads

num_places = numel(selected_place_ids);

total_size = 12*24*30*6; % num of data points: 12 * 24h * 30days * 6 months
block_size = 12*24*15; % 1 month blocks
num_blocks = total_size / block_size;
%display = 2;
display = 0;
iters = 100;

% load data
load norrecampus_imputation_multi75;

% use detrended time-series
for i=1:numel(y)
    y{i} = (y{i} - detrended_speeds{i}.removed_seasonality) / detrended_speeds{i}.removed_std;
    y_true{i} = (y_true{i} - detrended_speeds{i}.removed_seasonality) / detrended_speeds{i}.removed_std;
end

q = 1;  % dimensionality of the input
d = numel(selected_place_ids);  % dimensionality of the output
    
% compute lag matrices
n_lags = 5;
%lags_definition = [1:5, 7*12*24];
%lags_definition = [-n_lags:-1, 1:n_lags];
lags_definition = [-n_lags:-1, 1:n_lags, -7*12*24, 7*12*24];
lags = cell(d,1);
for place=1:numel(selected_place_ids)
    % find index for that place_id
    [~, ix] = max(cellfun(@(s) ~isempty(strfind(selected_place_ids{place}, s)), place_ids));
    lags{place} = lagmatrix(y{ix}, lags_definition);
    
    % add first order differences
    lags{place} = [lags{place} (lags{place}(:,n_lags) - lags{place}(:,n_lags-1))];
    lags{place} = [lags{place} (lags{place}(:,n_lags+1) - lags{place}(:,n_lags+2))];
    
    % do interpolation to fix nan's in the lags
    times = 1:size(lags{place},1);
    for i=1:size(lags{place},2)
        mask =  ~isnan(lags{place}(:,i));
        lags{place}(~mask,i) = interp1(times(mask), lags{place}(mask,i), times(~mask));
    end
    lags{place}(isnan(lags{place})) = mean(y_true{ix});
end

trues = cell(d,1);
preds_naive = cell(d,1); vars_naive = cell(d,1);
preds_cribbing = cell(d,1); vars_cribbing = cell(d,1);
preds_lr = cell(d,1); vars_lr = cell(d,1);
preds_knn = cell(d,1);
preds_svr = cell(d,1);
preds_interp = cell(d,1);
preds_ppca = cell(d,1);
last_obs = cell(d,1);
for place=1:numel(selected_place_ids)
    [~, ix] = max(cellfun(@(s) ~isempty(strfind(selected_place_ids{place}, s)), place_ids));
    last_obs{place} = 0;
end
for block=1:num_blocks
    fprintf('Running model for block %d of %d...\n', block, num_blocks);
    lo = (block-1)*block_size+1;
    hi = block*block_size;
    fprintf('lo=%d hi=%d\n', lo, hi);
    
    y_block = cell(d,1);
    y_true_block = cell(d,1);
    X_block = cell(d,1);
    missings = cell(d,1);
    non_missings = cell(d,1);
    X_train = cell(d,1);
    y_train = cell(d,1);
    X_test = cell(d,1);
    y_test = cell(d,1);
    removed_std = cell(d,1);
    removed_seasonality = cell(d,1);
    interp = cell(d,1);
    for place=1:numel(selected_place_ids)
        % find index for that place_id
        [~, ix] = max(cellfun(@(s) ~isempty(strfind(selected_place_ids{place}, s)), place_ids));
        
        y_block{place} = y{ix}(lo:hi);
        y_true_block{place} = y_true{ix}(lo:hi);
        X_block{place} = [1:size(y_block{place},1)]';
        assert(size(y_block{place},1) == size(y_block{place},1));
        
        % compute missings and non-missings
        missings{place} = isnan(y_block{place});
        non_missings{place} = X_block{place};
        non_missings{place}(missings{place}) = [];
        
        % normalize data
        mean_y = mean(y_true_block{place}); 
        std_y = std(y_true_block{place}); 
        y_block{place} = (y_block{place} - mean_y) / std_y;
        y_true_block{place} = (y_true_block{place} - mean_y) / std_y;
       
        removed_std{place} = detrended_speeds{ix}.removed_std;
        removed_seasonality{place} = detrended_speeds{ix}.removed_seasonality(lo:hi);
        
        % train/test split
        X_train{place} = X_block{place}(non_missings{place},:);
        y_train{place} = y_block{place}(non_missings{place},:);
        X_test{place} = X_block{place}(missings{place},:);
        y_test{place} = y_true_block{place}(missings{place},:) * removed_std{place} + removed_seasonality{place}(missings{place},end);
        
        trues{place} = [trues{place}; y_test{place}];
        
        % linear regression, KNN and SVR with lags from multiple places
        lags_train = []; 
        lags_test = [];
        for i=1:numel(y_block)
            lags_block = lags{i}(lo:hi,:);
            lags_train = [lags_train, lags_block(non_missings{place},:)];
            lags_test = [lags_test, lags_block(missings{place},:)];
        end
        
        % linear regression
        disp('Running linear regression on lags of multiple places...')
        lr_model = fitlm(lags_train, y_train{place});
        pred_lr = predict(lr_model, lags_test);
        pred_lr = pred_lr * removed_std{place} + removed_seasonality{place}(missings{place},end);
        preds_lr{place} = [preds_lr{place}; pred_lr];
        
        % KNN search
        disp('Running KNN on lags of multiple places...')
        [idx, dist] = knnsearch(lags_train, lags_test, 'K', 3, 'Distance', 'Euclidean');
        %pred_knn = mean(y_train{place}(idx),2) * removed_std{place} + removed_seasonality{place}(missings{place},end);
        % weighted version of knn regression
        weights = 1 ./ (dist.^2);
        weights = weights ./ repmat(sum(weights,2),1,size(weights,2));
        pred_knn = sum(weights .* y_train{place}(idx), 2) * removed_std{place} + removed_seasonality{place}(missings{place},end);
        %pred_knn = median(y_train{place}(idx),2) * removed_std{place} + removed_seasonality{place}(missings{place},end);
        preds_knn{place} = [preds_knn{place}; pred_knn];
        
        % SVR
        disp('Running SVR on lags of multiple places...')
        %svr_model = fitrsvm(lags_train, y_train{place},'Standardize',true,'KernelScale','auto','OptimizeHyperparameters','auto','HyperparameterOptimizationOptions',struct('AcquisitionFunctionName','expected-improvement-plus'));
        %svr_model = fitrsvm(lags_train, y_train{place},'Standardize',true,'KernelFunction','gaussian','KernelScale','auto');
        svr_model = fitrsvm(lags_train, y_train{place},'Standardize',true,'KernelScale','auto');
        pred_svr = predict(svr_model, lags_test);
        pred_svr = pred_svr * removed_std{place} + removed_seasonality{place}(missings{place},end);
        preds_svr{place} = [preds_svr{place}; pred_svr];
        
        % linear interpolation
        speeds_ts = timeseries(y_block{place}, 1:size(y_block{place},1) , 'name', ['Speeds', place_ids{i}]);
        speeds_ts.TimeInfo.Units = 'minutes';
        speeds_ts.TimeInfo.StartDate = ['01-Jan-2015'];     % Set start date.
        speeds_ts.TimeInfo.Format = 'mmm dd, yy';         
        speeds_ts = setuniformtime(speeds_ts,'Interval', 5);
        interpolation_method = 'linear';
        speeds_ts_rs = resample(speeds_ts, 0:5:size(y_block{place},1)*5-5, interpolation_method); 
        if isnan(speeds_ts_rs.Data(end))
            speeds_ts_rs.Data(end) = speeds_ts_rs.Data(end-1);
        end
        speeds_ts_rs.Data(isnan(speeds_ts_rs.Data)) = mean(speeds_ts_rs.Data(~isnan(speeds_ts_rs.Data)));
        pred_interp = speeds_ts_rs.Data(isnan(speeds_ts.Data)) * removed_std{place} + removed_seasonality{place}(missings{place},end);
        preds_interp{place} = [preds_interp{place}; pred_interp];
        interp{place} = speeds_ts_rs.Data;
        
    end
    
    csvwrite(['r_imputation/block_',num2str(block),'.csv'], reshape(cell2mat(y_block),size(y_block{1},1),num_places));
    csvwrite(['r_imputation/block_true_',num2str(block),'.csv'], reshape(cell2mat(y_true_block),size(y_block{1},1),num_places));
    csvwrite(['r_imputation/block_interp_',num2str(block),'.csv'], reshape(cell2mat(interp),size(interp{1},1),num_places));
    csvwrite(['r_imputation/mean_std_',num2str(block),'.csv'], [reshape(cell2mat(removed_std),size(removed_std{1},1),num_places); reshape(cell2mat(removed_seasonality),size(removed_seasonality{1},1),num_places)]);

    % PPCA: Approach 1
%     y_block_mat = reshape(cell2mat(y_block), 4320, 2);
%     [C, ss, mu, Z, Ximputed] = ppca_mv(y_block_mat,2,false);
%     for place=1:numel(selected_place_ids)
%        preds_ppca{place} = [preds_ppca{place}; Ximputed(missings{place},place) * removed_std{place} + removed_seasonality{place}(missings{place},end)];
%     end
    
    % PPCA: Approach 2
%     y_block_mat = reshape(y_block{1}, 15, 288);
%     for place=2:numel(selected_place_ids)
%         y_block_mat = [y_block_mat; reshape(y_block{place}, 15, 288)];
%     end
%     [C, ss, mu, Z, Ximputed] = ppca_mv(y_block_mat,3,false);
%     for place=1:numel(selected_place_ids)
%         imp = reshape(Ximputed(((place-1)*15+1):(place*15),:), 15*288, 1);
%         preds_ppca{place} = [preds_ppca{place}; imp(missings{place}) * removed_std{place} + removed_seasonality{place}(missings{place},end)];
%     end
    
    % PPCA: Approach 3
%     y_block_mat = lagmatrix(reshape(y_block{1}, 15, 288), [-1,0,1]);
%     for place=2:numel(selected_place_ids)
%         y_block_mat = [y_block_mat; lagmatrix(reshape(y_block{place}, 15, 288), [-1,0,1])];
%     end
%     [C, ss, mu, Z, Ximputed] = ppca_mv(y_block_mat,3,false);
%     for place=1:numel(selected_place_ids)
%         imp = reshape(Ximputed(((place-1)*15+1):(place*15),289:576), 15*288, 1);
%         preds_ppca{place} = [preds_ppca{place}; imp(missings{place}) * removed_std{place} + removed_seasonality{place}(missings{place},end)];
%     end
    
    % PPCA: Approach 3b (BEST)
    y_block_mat = lagmatrix(reshape(y_block{1}, 15, 288), [0,-1,1,-2,2]);
    for place=2:numel(selected_place_ids)
        y_block_mat = [y_block_mat; lagmatrix(reshape(y_block{place}, 15, 288), [0,-1,1,-2,2])];
    end
    [C, ss, mu, Z, Ximputed] = ppca_mv(y_block_mat,4,false);
    for place=1:numel(selected_place_ids)
        imp = reshape(Ximputed(((place-1)*15+1):(place*15),1:288), 15*288, 1);
        preds_ppca{place} = [preds_ppca{place}; imp(missings{place}) * removed_std{place} + removed_seasonality{place}(missings{place},end)];
    end
    
    % PPCA: Approach 3c
%     y_block_mat = [lagmatrix(reshape(y_block{1}, 15, 288), [0]); lagmatrix(reshape(y_block{1}, 15, 288), [-1]); lagmatrix(reshape(y_block{1}, 15, 288), [1])];
%     for place=2:numel(selected_place_ids)
%         y_block_mat = [y_block_mat; [lagmatrix(reshape(y_block{place}, 15, 288), [0]); lagmatrix(reshape(y_block{place}, 15, 288), [-1]); lagmatrix(reshape(y_block{place}, 15, 288), [1])]];
%     end
%     [C, ss, mu, Z, Ximputed] = ppca_mv(y_block_mat,3,false);
%     for place=1:3:(3*numel(selected_place_ids))
%         place
%         (place-1)*15+1
%         (place*15)
%         imp = reshape(Ximputed(((place-1)*15+1):(place*15),:), 15*288, 1);
%         pl = (place - 1) / 3 + 1
%         preds_ppca{pl} = [preds_ppca{pl}; imp(missings{pl}) * removed_std{pl} + removed_seasonality{pl}(missings{pl},end)];
%     end
    
    % compute error and show results
    fprintf('\nResults after %d blocks of %d:\n', block, num_blocks)
    for place=1:d
        % find index for that place_id
        [~, ix] = max(cellfun(@(s) ~isempty(strfind(selected_place_ids{place}, s)), place_ids));
        
        fprintf('\nPlace id: %s\n', place_ids{ix})
        fprintf('           CorrCoef\tMAE\tRMSE\tRAE \tRRSE\tR2\tMPE\n')
        [corr, mae, rmse, rae, rrse, r2, mpe] = eval_predictions(preds_interp{place}, trues{place});
        fprintf('Interp.:   %.3f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\n', corr, mae, rmse, rae, rrse, r2, mpe)
        [corr, mae, rmse, rae, rrse, r2, mpe] = eval_predictions(preds_knn{place}, trues{place});
        fprintf('KNN:       %.3f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\n', corr, mae, rmse, rae, rrse, r2, mpe)
        [corr, mae, rmse, rae, rrse, r2, mpe] = eval_predictions(preds_lr{place}, trues{place});
        fprintf('Lin. Reg.: %.3f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\n', corr, mae, rmse, rae, rrse, r2, mpe)
        [corr, mae, rmse, rae, rrse, r2, mpe] = eval_predictions(preds_svr{place}, trues{place});
        fprintf('SVR:       %.3f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\n', corr, mae, rmse, rae, rrse, r2, mpe)
        [corr, mae, rmse, rae, rrse, r2, mpe] = eval_predictions(preds_ppca{place}, trues{place});
        fprintf('PPCA:      %.3f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\n', corr, mae, rmse, rae, rrse, r2, mpe)
    end
end

